server_client_20150129_153949

### config1 : test_client_timeout

Result | Function execution time | Total execution time
--- | --- | ---
Failed | 61.3348400593 sec | 64.5535211563 sec

Error message: Did not properly handle client timeout

Naarad report

### Metrics

#### server1-perf

Submetric | max | mean | min | p50 | p75 | p90 | p95 | p99 | std
--- | --- | --- | --- | --- | --- | --- | --- | --- | ---
latency | 0.16 | 0.11 | 0.074 | 0.11 | 0.12 | 0.13 | 0.13 | 0.14 | 0.017
qps | 739.00 | 500.50 | 262.00 | 500.50 | 619.75 | 691.30 | 715.15 | 734.23 | 238.50

#### client1-perf

Submetric | max | mean | min | p50 | p75 | p90 | p95 | p99 | std
--- | --- | --- | --- | --- | --- | --- | --- | --- | ---
latency | 1192.71 | 1192.71 | 1192.71 | 1192.71 | 1192.71 | 1192.71 | 1192.71 | 1192.71 | 0.0
qps | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 0.0

### SLAs

metric | submetric | sla rule | value
--- | --- | --- | ---
server1-perf | latency | p50 lt 0.3 | 0.11
server1-perf | latency | mean lt 0.33 | 0.107526473526
server1-perf | qps | mean lt 7.0 | 500.5
server2-perf | latency | p50 lt 0.3 | None
server2-perf | latency | mean lt 0.33 | None
server2-perf | qps | mean lt 7.0 | None
server3-perf | latency | p50 lt 0.3 | None
server3-perf | latency | mean lt 0.33 | None
server3-perf | qps | mean lt 7.0 | None
client1-perf | latency | p50 lt 22.0 | 1192.713
client1-perf | latency | mean lt 35.0 | 1192.713
client1-perf | qps | mean lt 2.0 | 1.0
client2-perf | latency | p50 lt 22.0 | None
client2-perf | latency | mean lt 35.0 | None
client2-perf | qps | mean lt 2.0 | None